Displaying 6 results from an estimated 6 matches for "fb_modifier".
2017 May 18
5
[PATCH v3] drm: Add DRM_MODE_ROTATE_ and DRM_MODE_REFLECT_ to UAPI
...TATE_180) {
+ if (rotation & DRM_MODE_ROTATE_180) {
src_x += src_w - 1;
src_y += src_h - 1;
- } else if (rotation & DRM_REFLECT_X) {
+ } else if (rotation & DRM_MODE_REFLECT_X) {
src_x += src_w - 1;
}
}
@@ -3271,17 +3271,17 @@ static u32 skl_plane_ctl_tiling(uint64_t fb_modifier)
static u32 skl_plane_ctl_rotation(unsigned int rotation)
{
switch (rotation) {
- case DRM_ROTATE_0:
+ case DRM_MODE_ROTATE_0:
break;
/*
- * DRM_ROTATE_ is counter clockwise to stay compatible with Xrandr
+ * DRM_MODE_ROTATE_ is counter clockwise to stay compatible with Xrandr
* while...
2017 May 19
4
[PATCH v4 1/2] drm/blend: Fix comment typ-o
Fix DRM_REFELCT_Y -> DRM_REFLECT_Y.
Signed-off-by: Robert Foss <robert.foss at collabora.com>
---
drivers/gpu/drm/drm_blend.c | 2 +-
1 file changed, 1 insertion(+), 1 deletion(-)
diff --git a/drivers/gpu/drm/drm_blend.c b/drivers/gpu/drm/drm_blend.c
index a0d0d6843288..dee67ef6c670 100644
--- a/drivers/gpu/drm/drm_blend.c
+++ b/drivers/gpu/drm/drm_blend.c
@@ -129,7 +129,7 @@
*
2017 May 19
2
[PATCH v4 2/2] drm: Add DRM_MODE_ROTATE_ and DRM_MODE_REFLECT_ to UAPI
...TATE_180) {
+ if (rotation & DRM_MODE_ROTATE_180) {
src_x += src_w - 1;
src_y += src_h - 1;
- } else if (rotation & DRM_REFLECT_X) {
+ } else if (rotation & DRM_MODE_REFLECT_X) {
src_x += src_w - 1;
}
}
@@ -3271,17 +3271,17 @@ static u32 skl_plane_ctl_tiling(uint64_t fb_modifier)
static u32 skl_plane_ctl_rotation(unsigned int rotation)
{
switch (rotation) {
- case DRM_ROTATE_0:
+ case DRM_MODE_ROTATE_0:
break;
/*
* DRM_ROTATE_ is counter clockwise to stay compatible with Xrandr
* while...
2017 May 18
0
@@ -3271,17 +3271,17 @@ static u32 skl_plane_ctl_tiling(uint64_t fb_modifier)
break;
/*
- * DRM_ROTATE_ is counter clockwise to stay compatible with Xrandr
+ * DRM_MODE_ROTATE_ is counter clockwise to stay compatible with Xrandr
* while...
2017 May 18
[PATCH v3] drm: Add DRM_MODE_ROTATE_ and DRM_MODE_REFLECT_ to UAPI
...DE_ROTATE_180) {
> src_x += src_w - 1;
> src_y += src_h - 1;
> - } else if (rotation & DRM_REFLECT_X) {
> + } else if (rotation & DRM_MODE_REFLECT_X) {
> src_x += src_w - 1;
> }
> }
> @@ -3271,17 +3271,17 @@ static u32 skl_plane_ctl_tiling(uint64_t fb_modifier)
> static u32 skl_plane_ctl_rotation(unsigned int rotation)
> {
> switch (rotation) {
> - case DRM_ROTATE_0:
> + case DRM_MODE_ROTATE_0:
> break;
> /*
> - * DRM_ROTATE_ is counter clockwise to stay compatible with Xrandr
> + * DRM_MODE_ROTATE_ is counter clockw...
2017 May 22
0
[PATCH v4 2/2] drm: Add DRM_MODE_ROTATE_ and DRM_MODE_REFLECT_ to UAPI
...DE_ROTATE_180) {
> src_x += src_w - 1;
> src_y += src_h - 1;
> - } else if (rotation & DRM_REFLECT_X) {
> + } else if (rotation & DRM_MODE_REFLECT_X) {
> src_x += src_w - 1;
> }
> }
> @@ -3271,17 +3271,17 @@ static u32 skl_plane_ctl_tiling(uint64_t fb_modifier)
> static u32 skl_plane_ctl_rotation(unsigned int rotation)
> {
> switch (rotation) {
> - case DRM_ROTATE_0:
> + case DRM_MODE_ROTATE_0:
> break;
> /*
> - * DRM_ROTATE_ is counter clockwise to stay compatible with Xrandr
> + * DRM_MODE_ROTATE_ is counter clockw...
2017 May 22
0
[PATCH v4 2/2] drm: Add DRM_MODE_ROTATE_ and DRM_MODE_REFLECT_ to UAPI
...DE_ROTATE_180) {
> src_x += src_w - 1;
> src_y += src_h - 1;
> - } else if (rotation & DRM_REFLECT_X) {
> + } else if (rotation & DRM_MODE_REFLECT_X) {
> src_x += src_w - 1;
> }
> }
> @@ -3271,17 +3271,17 @@ static u32 skl_plane_ctl_tiling(uint64_t fb_modifier)
> static u32 skl_plane_ctl_rotation(unsigned int rotation)
> {
> switch (rotation) {
> - case DRM_ROTATE_0:
> + case DRM_MODE_ROTATE_0:
> break;
> /*
> - * DRM_ROTATE_ is counter clockwise to stay compatible with Xrandr
> + * DRM_MODE_ROTATE_ is counter clockw...